<?php
namespace Dominie\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
* Elementor Widget
* Elementor widget for Dominie.
* @since 1.0.0
**/
class Dmne_Instructor extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 * @since 1.0.0
	 * @access public
	 * @return string Widget name.
	**/
	public function get_name() {
		return 'dmne-instructor';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Dmne Instructor', 'dominie' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-posts-group';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'dominie_widgets' ];
	}

	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ 'dominie' ];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => esc_html__( 'Content', 'dominie' ),
			]
		);

		$this->add_control(
			'instructor-column',
			[
				'label' => __( 'Course Column Style', 'dominie' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'col-lg-3',
				'options' => [
					'col-lg-3' => __( 'col-lg-3', 'dominie' ),
					'col-lg-4' => __( 'col-lg-4', 'dominie' ),
					'col-lg-6' => __( 'col-lg-6', 'dominie' ),
				],
			]
		);

		$this->add_control(
			'post-order',
			[
				'label' => __( 'Post Order', 'dominie' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'ASC',
				'options' => [
					'ASC' => __( 'ASC', 'dominie' ),
					'DSC' => __( 'DSC', 'dominie' ),
				],
			]
		);
		$this->add_control(
			'post-limit',
			[
				'label'       => esc_html__( 'Post Limit', 'dominie' ),
				'type'        => Controls_Manager::TEXT,
				'description' => esc_html__( 'How Many Post You Display', 'dominie' ),
				'default'     => esc_html__('-1','dominie')
			]
		);
		$this->add_control(
			'post-offset',
			[
				'label'       => esc_html__( 'Post Offset', 'dominie' ),
				'type'        => Controls_Manager::TEXT,
				'description' => esc_html__( 'How Many Post You Offset', 'dominie' ),
				'default'     => esc_html__('0','dominie')
			]
		);



		$this->end_controls_section();

		$this->start_controls_section(
			'section_style',
			[
				'label' => esc_html__( 'Style', 'dominie' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'text_transform',
			[
				'label' => esc_html__( 'Text Transform', 'dominie' ),
				'type' => Controls_Manager::SELECT,
				'default' => '',
				'options' => [
					'' => esc_html__( 'None', 'dominie' ),
					'uppercase' => esc_html__( 'UPPERCASE', 'dominie' ),
					'lowercase' => esc_html__( 'lowercase', 'dominie' ),
					'capitalize' => esc_html__( 'Capitalize', 'dominie' ),
				],
				'selectors' => [
					'{{WRAPPER}} .title' => 'text-transform: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	*/
	protected function render() {
		$settings = $this->get_settings_for_display(); 
		$instructor_column  = (isset($settings['instructor-column']) ? $settings['instructor-column'] : 'col-lg-3');  

		global $post; 
		$course_query = new \WP_Query(array('post_type'=> 'courses', 'order'=> $settings['post-order'], 'posts_per_page' => $settings['post-limit'], 'offset' => $settings['post-offset'] )); ?>

		<div class="row">
			<?php if($course_query->have_posts()) : 
				while($course_query->have_posts()) : $course_query->the_post(); 

					$instructors = tutor_utils()->get_instructors_by_course();
					if ($instructors){
						foreach ($instructors as $instructor){ 
							$profile_url = tutor_utils()->profile_url($instructor->ID); ?>

							<div class="<?php echo $instructor_column ?> col-md-6 col-sm-6">
			                    <div class="single-instructor-inner">
			                        <div class="thumb">
			                            <?php echo tutor_utils()->get_tutor_avatar($instructor->ID, 'dominie-instructor-thumbnail'); ?>
										<?php
											$instructor_rating = tutor_utils()->get_instructor_ratings($instructor->ID);
										    if (!empty($instructor_rating)) { ?>
												<?php 
													if ($instructor_rating->rating_avg > 0) { ?>
														<div class="rating">
									        				<?php echo  apply_filters('tutor_course_rating_average', $instructor_rating->rating_avg);
									        				echo '/5 <i class="fa fa-star"></i>'; ?>
									        			</div>
													<?php } 
												?>
											<?php }
										?>
			                        </div>
			                        <div class="details">
			                            <h5><a href="<?php echo $profile_url; ?>"><?php echo $instructor->display_name; ?></a></h5>
			                            <p><?php echo tutor_utils()->get_course_count_by_instructor($instructor->ID); ?> <?php _e('Courses', 'dominie'); ?></p>
			                        </div>
			                    </div>
			                </div>
						<?php }
					}
            	endwhile;
			endif; ?>
		</div>
	<?php }
}